#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/2/28 16:00
Desc: 广州期货交易所-业务/服务-合约信息
http://www.gfex.com.cn/gfex/hyxx/ywcs.shtml
"""

import pandas as pd
import requests


def futures_contract_info_gfex() -> pd.DataFrame:
    """
    广州期货交易所-业务/服务-合约信息
    http://www.gfex.com.cn/gfex/hyxx/ywcs.shtml
    :return: 交易参数汇总查询
    :rtype: pandas.DataFrame
    """
    url = "http://www.gfex.com.cn/u/interfacesWebTtQueryContractInfo/loadList"
    params = {
        "variety": "",
        "trade_type": "0",
    }
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36"
    }
    r = requests.post(url, params=params, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df.rename(
        columns={
            "tradeType": "-",
            "variety": "品种",
            "varietyOrder": "-",
            "contractId": "合约代码",
            "unit": "交易单位",
            "tick": "最小变动单位",
            "startTradeDate": "开始交易日",
            "endTradeDate": "最后交易日",
            "endDeliveryDate0": "最后交割日",
        },
        inplace=True,
    )
    temp_df["交易单位"] = pd.to_numeric(temp_df["交易单位"], errors="coerce")
    temp_df["最小变动单位"] = pd.to_numeric(temp_df["最小变动单位"], errors="coerce")
    temp_df["开始交易日"] = pd.to_datetime(
        temp_df["开始交易日"], format="%Y%m%d", errors="coerce"
    ).dt.date
    temp_df["最后交易日"] = pd.to_datetime(
        temp_df["最后交易日"], format="%Y%m%d", errors="coerce"
    ).dt.date
    temp_df["最后交割日"] = pd.to_datetime(
        temp_df["最后交割日"], format="%Y%m%d", errors="coerce"
    ).dt.date
    temp_df = temp_df[
        [
            "品种",
            "合约代码",
            "交易单位",
            "最小变动单位",
            "开始交易日",
            "最后交易日",
            "最后交割日",
        ]
    ]
    return temp_df


if __name__ == "__main__":
    futures_contract_info_gfex_df = futures_contract_info_gfex()
    print(futures_contract_info_gfex_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/7/21 15:00
Desc: 每日注册仓单数据
大连商品交易所, 上海期货交易所, 郑州商品交易所, 广州期货交易所
"""

import datetime
import re
import warnings
from io import BytesIO
from typing import List

import pandas as pd
import requests

from akshare.futures import cons
from akshare.futures.requests_fun import requests_link, pandas_read_html_link
from akshare.futures.symbol_var import chinese_to_english

calendar = cons.get_calendar()
shfe_20100126 = pd.DataFrame(
    {
        "var": ["CU", "AL", "ZN", "RU", "FU", "AU", "RB", "WR"],
        "receipt": [29783, 285396, 187713, 116435, 376200, 12, 145648, 0],
    }
)
shfe_20101029 = pd.DataFrame(
    {
        "var": ["CU", "AL", "ZN", "RU", "FU", "AU", "RB", "WR"],
        "receipt": [39214, 359729, 182562, 25990, 313600, 27, 36789, 0],
    }
)


def get_dce_receipt(date: str = None, vars_list: List = cons.contract_symbols):
    """
    大连商品交易所-注册仓单数据
    http://www.dce.com.cn/dce/channel/list/187.html
    :param date: 开始日期: YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象, 为空时为当天
    :type date: str
    :param vars_list: 合约品种如 RB, AL等列表, 为空时为所有商品数据从 20060106开始，每周五更新仓单数据。直到20090407起，每交易日都更新仓单数据
    :type vars_list: list
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        return warnings.warn("vars_list: 必须是列表")
    date = cons.convert_date(date) if date is not None else datetime.date.today()
    if date.strftime("%Y%m%d") not in calendar:
        warnings.warn(f"{date.strftime('%Y%m%d')}非交易日")
        return None
    url = "http://www.dce.com.cn/dcereport/publicweb/dailystat/wbillWeeklyQuotes"
    payload = {
        "tradeDate": date.strftime("%Y%m%d"),
        "varietyId": "all",
    }
    r = requests.post(url, json=payload)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['entityList'])
    records = pd.DataFrame()
    for x in temp_df.to_dict(orient="records"):
        if isinstance(x["variety"], str):
            if x["variety"][-2:] == "小计":
                var = x["variety"][:-2]
                temp_data = {
                    "var": chinese_to_english(var),
                    "receipt": int(x["wbillQty"]),
                    "receipt_chg": int(x["diff"]),
                    "date": date.strftime("%Y%m%d"),
                }
                records = pd.concat([records, pd.DataFrame(temp_data, index=[0])])

    if len(records.index) != 0:
        records.index = records["var"]
        vars_in_market = [i for i in vars_list if i in records.index]
        records = records.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_shfe_receipt_1(
    date: str = None, vars_list: List = cons.contract_symbols
) -> pd.DataFrame:
    """
    上海期货交易所-注册仓单数据-类型1
    适用 20081006 至 20140518(包括)、20100126、20101029日期交易所格式混乱，直接回复脚本中 pandas.DataFrame, 20100416、20130821日期交易所数据丢失
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象为空时为当天
    :type date: str
    :param vars_list: 合约品种如RB、AL等列表为空时为所有商品
    :type vars_list: list
    :return: 注册仓单数据-类型1
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        raise warnings.warn("symbol_list: 必须是列表")
    date = (
        cons.convert_date(date).strftime("%Y%m%d")
        if date is not None
        else datetime.date.today()
    )
    if date not in calendar:
        warnings.warn(f"{date.strftime('%Y%m%d')}非交易日")
        return pd.DataFrame()
    if date == "20100126":
        shfe_20100126["date"] = date
        return shfe_20100126
    elif date == "20101029":
        shfe_20101029["date"] = date
        return shfe_20101029
    elif date in ["20100416", "20130821"]:
        print("20100416、20130821交易所数据丢失")
        return pd.DataFrame()
    else:
        var_list = [
            "天然橡胶",
            "沥青仓库",
            "沥青厂库",
            "热轧卷板",
            "燃料油",
            "白银",
            "线材",
            "螺纹钢",
            "铅",
            "铜",
            "铝",
            "锌",
            "黄金",
            "锡",
            "镍",
        ]
        url = cons.SHFE_RECEIPT_URL_1 % date
        data = pandas_read_html_link(url)[0]
        indexes = [x for x in data.index if (data[0].tolist()[x] in var_list)]
        last_index = [x for x in data.index if "注" in str(data[0].tolist()[x])][0] - 1
        records = pd.DataFrame()
        for i in list(range(len(indexes))):
            if i != len(indexes) - 1:
                data_cut = data.loc[indexes[i] : indexes[i + 1] - 1, :]
            else:
                data_cut = data.loc[indexes[i] : last_index, :]
                data_cut = data_cut.fillna(method="pad")
            data_dict = dict()
            data_dict["var"] = chinese_to_english(data_cut[0].tolist()[0])
            data_dict["receipt"] = int(data_cut[2].tolist()[-1])
            data_dict["receipt_chg"] = int(data_cut[3].tolist()[-1])
            data_dict["date"] = date
            records = pd.concat([records, pd.DataFrame(data_dict, index=[0])])
    if len(records.index) != 0:
        records.index = records["var"]
        vars_in_market = [i for i in vars_list if i in records.index]
        records = records.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_shfe_receipt_2(
    date: str = None, vars_list: List = cons.contract_symbols
) -> pd.DataFrame:
    """
    上海商品交易所-注册仓单数据-类型2
    适用 20140519(包括)-至今
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
    :type date: str
    :param vars_list: 合约品种如 RB、AL 等列表 为空时为所有商品
    :type vars_list: list
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        raise warnings.warn("symbol_list: 必须是列表")
    date = (
        cons.convert_date(date).strftime("%Y%m%d")
        if date is not None
        else datetime.date.today()
    )
    if date not in calendar:
        warnings.warn("%s 非交易日" % date.strftime("%Y%m%d"))
        return pd.DataFrame()
    url = cons.SHFE_RECEIPT_URL_20250701 % date
    r = requests_link(url, encoding="utf-8", headers=cons.shfe_headers)
    try:
        context = r.json()
    except:  # noqa: E722
        return pd.DataFrame()
    data = pd.DataFrame(context["o_cursor"])
    if len(data.columns) < 1:
        return pd.DataFrame()
    records = pd.DataFrame()
    for var in set(data["VARNAME"].tolist()):
        data_cut = data[data["VARNAME"] == var]
        if "BC" in var:
            data_dict = {
                "var": "BC",
                "receipt": int(data_cut["WRTWGHTS"].tolist()[-1]),
                "receipt_chg": int(data_cut["WRTCHANGE"].tolist()[-1]),
                "date": date,
            }
        else:
            data_dict = {
                "var": chinese_to_english(re.sub(r"\W|[a-zA-Z]", "", var)),
                "receipt": int(data_cut["WRTWGHTS"].tolist()[-1]),
                "receipt_chg": int(data_cut["WRTCHANGE"].tolist()[-1]),
                "date": date,
            }
        records = pd.concat([records, pd.DataFrame(data_dict, index=[0])])
        temp_records = (
            records.groupby("var")[["receipt", "receipt_chg"]].sum().reset_index()
        )
        temp_records["date"] = date
        records = temp_records
    if len(records.index) != 0:
        records.index = records["var"]
        vars_in_market = [i for i in vars_list if i in records.index]
        records = records.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_czce_receipt_1(date: str = None, vars_list: List = cons.contract_symbols):
    """
    郑州商品交易所-注册仓单数据
    适用 20080222 至 20100824(包括)
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
    :type date: str
    :param vars_list: list
    :type vars_list: 合约品种如 CF、TA 等列表 为空时为所有商品
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    date = (
        cons.convert_date(date).strftime("%Y%m%d")
        if date is not None
        else datetime.date.today()
    )
    if date not in calendar:
        warnings.warn("%s非交易日" % date.strftime("%Y%m%d"))
        return None
    if date == "20090820":
        return pd.DataFrame()
    url = cons.CZCE_RECEIPT_URL_1 % date
    r = requests_link(url, encoding="utf-8", headers=cons.shfe_headers)
    context = r.text
    data = pd.read_html(context)[1]
    records = pd.DataFrame()
    indexes = [x for x in data.index if "品种：" in str(data[0].tolist()[x])]
    ends = [x for x in data.index if "总计" in str(data[0].tolist()[x])]
    for i in list(range(len(indexes))):
        if i != len(indexes) - 1:
            data_cut = data.loc[indexes[i]: ends[i], :]
            data_cut = data_cut.fillna(method="pad")
        else:
            data_cut = data.loc[indexes[i]:, :]
            data_cut = data_cut.fillna(method="pad")
        if "PTA" in data_cut[0].tolist()[0]:
            var = "TA"
        else:
            var = chinese_to_english(re.sub(r"[A-Z]+", "", data_cut[0].tolist()[0][3:]))
        if var == "CF":
            receipt = data_cut[6].tolist()[-1]
            receipt_chg = data_cut[7].tolist()[-1]
        else:
            receipt = data_cut[5].tolist()[-1]
            receipt_chg = data_cut[6].tolist()[-1]
        data_dict = {
            "var": var,
            "receipt": int(receipt),
            "receipt_chg": int(receipt_chg),
            "date": date,
        }
        records = pd.concat([records, pd.DataFrame(data_dict, index=[0])])
    if len(records.index) != 0:
        records.index = records["var"]
        vars_in_market = [i for i in vars_list if i in records.index]
        records = records.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_czce_receipt_2(date: str = None, vars_list: List = cons.contract_symbols):
    """
    郑州商品交易所-注册仓单数据
    http://www.czce.com.cn/cn/jysj/cdrb/H770310index_1.htm
    适用 20100825(包括) - 20151111(包括)
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
    :type date: str
    :param vars_list: 合约品种如 CF、TA 等列表为空时为所有商品
    :type vars_list: list
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        return warnings.warn("symbol_list: 必须是列表")
    date = (
        cons.convert_date(date).strftime("%Y%m%d")
        if date is not None
        else datetime.date.today()
    )
    if date not in calendar:
        warnings.warn("%s非交易日" % date.strftime("%Y%m%d"))
        return None
    url = cons.CZCE_RECEIPT_URL_2 % (date[:4], date)
    r = requests.get(url)
    r.encoding = "utf-8"
    data = pd.read_html(r.text)[3:]
    records = pd.DataFrame()
    for data_cut in data:
        if len(data_cut.columns) > 3:
            last_indexes = [
                x for x in data_cut.index if "注：" in str(data_cut[0].tolist()[x])
            ]
            if len(last_indexes) > 0:
                last_index = last_indexes[0] - 1
                data_cut = data_cut.loc[:last_index, :]
            if "PTA" in data_cut[0].tolist()[0]:
                var = "TA"
            else:
                strings = data_cut[0].tolist()[0]
                string = strings.split(" ")[0][3:]
                var = chinese_to_english(re.sub(r"[A-Z]+", "", string))
            data_cut.columns = data_cut.T[1].tolist()
            receipt = data_cut["仓单数量"].tolist()[-1]
            receipt_chg = data_cut["当日增减"].tolist()[-1]
            data_dict = {
                "var": var,
                "receipt": int(receipt),
                "receipt_chg": int(receipt_chg),
                "date": date,
            }
            records = pd.concat([records, pd.DataFrame(data_dict, index=[0])])
    if len(records.index) != 0:
        records.index = records["var"]
        vars_in_market = [i for i in vars_list if i in records.index]
        records = records.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_czce_receipt_3(
    date: str = None, vars_list: List = cons.contract_symbols
) -> pd.DataFrame:
    """
    郑州商品交易所-注册仓单数据
    适用 20151008-至今
    http://www.czce.com.cn/cn/jysj/cdrb/H770310index_1.htm
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
    :type date: str
    :param vars_list: 合约品种如 CF、TA 等列表为空时为所有商品
    :type vars_list: list
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        print("vars_list: 必须是列表")
        return pd.DataFrame()
    date = (
        cons.convert_date(date).strftime("%Y%m%d")
        if date is not None
        else datetime.date.today()
    )
    if date not in calendar:
        warnings.warn("%s非交易日" % date.strftime("%Y%m%d"))
        return pd.DataFrame()
    url = f"http://www.czce.com.cn/cn/DFSStaticFiles/Future/{date[:4]}/{date}/FutureDataWhsheet.xls"
    r = requests_link(url, encoding="utf-8", headers=cons.shfe_headers)
    temp_df = pd.read_excel(BytesIO(r.content))
    temp_df = temp_df[
        [
            bool(1 - item)
            for item in [
                item if item is not pd.NA else False
                for item in temp_df.iloc[:, 0].str.contains("非农产品")
            ]
        ]
    ]
    temp_df.reset_index(inplace=True, drop=True)
    range_list_one = list(
        temp_df[
            [
                item if not pd.isnull(item) else False
                for item in temp_df.iloc[:, 0].str.contains("品种")
            ]
        ].index
    )
    range_list_two = list(
        temp_df[
            [
                item if not pd.isnull(item) else False
                for item in temp_df.iloc[:, 0].str.contains("品种")
            ]
        ].index
    )[1:]
    range_list_two.append(None)
    symbol_list = []
    receipt_list = []
    receipt_chg_list = []
    records = pd.DataFrame()
    for page in range(len(range_list_one)):
        inner_df = temp_df[range_list_one[page] : range_list_two[page]]
        reg = re.compile(r"[A-Z]+")
        try:
            symbol = reg.findall(inner_df.iloc[0, 0])[0]
        except:  # noqa: E722
            continue
        symbol_list.append(symbol)
        inner_df.columns = inner_df.iloc[1, :]
        inner_df = inner_df.iloc[2:, :]
        inner_df = inner_df.dropna(axis=1, how="all")
        if symbol == "PTA":
            try:
                receipt_list.append(
                    inner_df["仓单数量(完税)"].iloc[-1]
                    + int(inner_df["仓单数量(保税)"].iloc[-1])
                )  # 20210316 TA 分为保税和完税
            except:  # noqa: E722
                receipt_list.append(0)
        elif symbol == "MA":
            try:
                try:
                    receipt_list.append(
                        inner_df["仓单数量(完税)"].iloc[-2]
                        + int(inner_df["仓单数量(保税)"].iloc[-2])
                    )  # 20210316 MA 分为保税和完税
                except:  # noqa: E722
                    receipt_list.append(
                        inner_df["仓单数量(完税)"].iloc[-2]
                    )  # 处理 MA 的特殊格式
            except:  # noqa: E722
                receipt_list.append(0)
        else:
            try:
                receipt_list.append(inner_df["仓单数量"].iloc[-1])
            except:  # noqa: E722
                receipt_list.append(0)
        if symbol == "MA":
            receipt_chg_list.append(inner_df["当日增减"].iloc[-2])
        else:
            receipt_chg_list.append(inner_df["当日增减"].iloc[-1])
    data_df = pd.DataFrame(
        [symbol_list, receipt_list, receipt_chg_list, [date] * len(receipt_chg_list)]
    ).T
    data_df.columns = ["var", "receipt", "receipt_chg", "date"]
    temp_list = data_df["var"].tolist()
    data_df["var"] = [item if item != "PTA" else "TA" for item in temp_list]
    if len(data_df.index) != 0:
        data_df.index = data_df["var"]
        vars_in_market = [i for i in vars_list if i in data_df.index]
        records = data_df.loc[vars_in_market, :]
    return records.reset_index(drop=True)


def get_gfex_receipt(
    date: str = None, vars_list: List = cons.contract_symbols
) -> pd.DataFrame:
    """
    广州期货交易所-注册仓单数据
    http://www.gfex.com.cn/gfex/cdrb/hqsj_tjsj.shtml
    :param date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date对象 为空时为当天
    :type date: str
    :param vars_list: 合约品种如 SI 等列表为空时为所有商品
    :type vars_list: list
    :return: 注册仓单数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        raise warnings.warn("vars_list: 必须是列表")
    date = cons.convert_date(date) if date is not None else datetime.date.today()
    if date.strftime("%Y%m%d") not in calendar:
        warnings.warn(f"{date.strftime('%Y%m%d')}非交易日")
        return pd.DataFrame()
    url = "http://www.gfex.com.cn/u/interfacesWebTdWbillWeeklyQuotes/loadList"
    payload = {"gen_date": date.isoformat().replace("-", "")}
    headers = {
        "Accept": "application/json, text/javascript, */*; q=0.01",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9,en;q=0.8",
        "Cache-Control": "no-cache",
        "Content-Length": "32",
        "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
        "Host": "www.gfex.com.cn",
        "Origin": "http://www.gfex.com.cn",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "http://www.gfex.com.cn/gfex/rihq/hqsj_tjsj.shtml",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
        "content-type": "application/x-www-form-urlencoded",
    }
    r = requests.post(url, data=payload, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    temp_df = temp_df[temp_df["variety"].str.contains("小计")]
    result_df = temp_df[["wbillQty", "diff"]].copy()
    if result_df.empty:
        return pd.DataFrame()

    result_df.loc[:, "date"] = date.isoformat().replace("-", "")
    result_df.loc[:, "var"] = [
        item.upper() for item in temp_df["varietyOrder"].tolist()
    ]
    result_df.reset_index(drop=True, inplace=True)
    result_df.rename(
        columns={
            "wbillQty": "receipt",
            "diff": "receipt_chg",
        },
        inplace=True,
    )
    result_df = result_df[["var", "receipt", "receipt_chg", "date"]]
    result_df.set_index(keys=["var"], inplace=True)
    if "LC" not in result_df.index:
        vars_list.remove("LC")
    if "PS" not in result_df.index:
        vars_list.remove("PS")
    result_df = result_df.loc[vars_list, :]
    result_df.reset_index(inplace=True)
    return result_df


def get_receipt(
    start_date: str = None,
    end_date: str = None,
    vars_list: List = cons.contract_symbols,
):
    """
    大宗商品-注册仓单数据
    :param start_date: 开始日期 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date 对象 为空时为当天
    :type start_date: str
    :param end_date: 结束数据 format：YYYY-MM-DD 或 YYYYMMDD 或 datetime.date 对象 为空时为当天
    :type end_date: str
    :param vars_list: 合约品种如 RB、AL 等列表为空时为所有商品
    :type vars_list: str
    :return: 展期收益率数据
    :rtype: pandas.DataFrame
    """
    if not isinstance(vars_list, list):
        return warnings.warn("vars_list: 必须是列表")
    start_date = (
        cons.convert_date(start_date)
        if start_date is not None
        else datetime.date.today()
    )
    end_date = (
        cons.convert_date(end_date)
        if end_date is not None
        else cons.convert_date(cons.get_latest_data_date(datetime.datetime.now()))
    )
    records = pd.DataFrame()
    while start_date <= end_date:
        if start_date.strftime("%Y%m%d") not in calendar:
            warnings.warn(f"{start_date.strftime('%Y%m%d')} 非交易日")
        else:
            print(start_date)
            for market, market_vars in cons.market_exchange_symbols.items():
                if market == "dce":
                    if start_date >= datetime.date(2009, 4, 7):
                        f = get_dce_receipt
                    else:
                        print("20090407 起，大连商品交易所每个交易日更新仓单数据")
                        f = None
                elif market == "shfe":
                    if (
                        datetime.date(2008, 10, 6)
                        <= start_date
                        <= datetime.date(2014, 5, 16)
                    ):
                        f = get_shfe_receipt_1
                    elif start_date > datetime.date(2014, 5, 16):
                        f = get_shfe_receipt_2
                    else:
                        f = None
                        print("20081006 起，上海期货交易所每个交易日更新仓单数据")
                elif market == "gfex":
                    if start_date > datetime.date(2022, 12, 22):
                        f = get_gfex_receipt
                    else:
                        f = None
                        print("20081006 起，上海期货交易所每个交易日更新仓单数据")
                elif market == "czce":
                    if (
                        datetime.date(2008, 3, 3)
                        <= start_date
                        <= datetime.date(2010, 8, 24)
                    ):
                        f = get_czce_receipt_1
                    elif (
                        datetime.date(2010, 8, 24)
                        < start_date
                        <= datetime.date(2015, 11, 11)
                    ):
                        f = get_czce_receipt_2
                    elif start_date > datetime.date(2015, 11, 11):
                        f = get_czce_receipt_3
                    else:
                        f = None
                        print("20080303 起，郑州商品交易所每个交易日更新仓单数据")
                get_vars = [var for var in vars_list if var in market_vars]
                if market != "cffex" and get_vars != []:
                    if f is not None:
                        records = pd.concat([records, f(start_date, get_vars)])
        start_date += datetime.timedelta(days=1)
    records.reset_index(drop=True, inplace=True)
    if records.empty:
        return records
    return records


if __name__ == "__main__":
    get_receipt_df = get_receipt(start_date="20251027", end_date="20251027")
    print(get_receipt_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/9/11 13:00
Desc: 东方财富-港股-公司概况
https://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=03900&type=web&color=w#/CompanyProfile
"""

import pandas as pd
import requests


def stock_hk_security_profile_em(symbol: str = "03900") -> pd.DataFrame:
    """
    东方财富-港股-证券资料
    https://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=03900&type=web&color=w#/CompanyProfile
    :param symbol: 股票代码
    :type symbol: str
    :return: 证券资料
    :rtype: pandas.DataFrame
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'
    params = {
        'reportName': 'RPT_HKF10_INFO_SECURITYINFO',
        'columns': 'SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,SECURITY_TYPE,LISTING_DATE,ISIN_CODE,BOARD,'
                   'TRADE_UNIT,TRADE_MARKET,GANGGUTONGBIAODISHEN,GANGGUTONGBIAODIHU,PAR_VALUE,'
                   'ISSUE_PRICE,ISSUE_NUM,YEAR_SETTLE_DAY',
        'quoteColumns': '',
        'filter': f'(SECUCODE="{symbol}.HK")',
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'F10',
        'client': 'PC',
        'v': '04748497219912483'
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['result']['data'])
    field_mapping = {
        "BOARD": "板块",
        "GANGGUTONGBIAODIHU": "是否沪港通标的",
        "GANGGUTONGBIAODISHEN": "是否深港通标的",
        "ISIN_CODE": "ISIN（国际证券识别编码）",
        "ISSUE_NUM": "发行量(股)",
        "ISSUE_PRICE": "发行价",
        "LISTING_DATE": "上市日期",
        "PAR_VALUE": "每股面值",
        "SECUCODE": "证券代码",
        "SECURITY_NAME_ABBR": "证券简称",
        "SECURITY_TYPE": "证券类型",
        "TRADE_MARKET": "交易所",
        "TRADE_UNIT": "每手股数",
        "YEAR_SETTLE_DAY": "年结日"
    }
    temp_df.rename(columns=field_mapping, inplace=True)
    temp_df = temp_df[[
        "证券代码",
        "证券简称",
        "上市日期",
        "证券类型",
        "发行价",
        "发行量(股)",
        "每手股数",
        "每股面值",
        "交易所",
        "板块",
        "年结日",
        "ISIN（国际证券识别编码）",
        "是否沪港通标的",
        "是否深港通标的",
    ]]
    return temp_df


def stock_hk_company_profile_em(symbol: str = "03900") -> pd.DataFrame:
    """
    东方财富-港股-公司资料
    https://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=03900&type=web&color=w#/CompanyProfile
    :param symbol: 股票代码
    :type symbol: str
    :return: 公司资料
    :rtype: pandas.DataFrame
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'
    params = {
        'reportName': 'RPT_HKF10_INFO_ORGPROFILE',
        'columns': 'SECUCODE,SECURITY_CODE,ORG_NAME,ORG_EN_ABBR,BELONG_INDUSTRY,FOUND_DATE,CHAIRMAN,'
                   'SECRETARY,ACCOUNT_FIRM,REG_ADDRESS,ADDRESS,YEAR_SETTLE_DAY,EMP_NUM,ORG_TEL,ORG_FAX,ORG_EMAIL,'
                   'ORG_WEB,ORG_PROFILE,REG_PLACE',
        'quoteColumns': '',
        'filter': f'(SECUCODE="{symbol}.HK")',
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '',
        'sortColumns': '',
        'source': 'F10',
        'client': 'PC',
        'v': '04748497219912483'
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['result']['data'])
    field_mapping = {
        'ACCOUNT_FIRM': '核数师',
        'ADDRESS': '办公地址',
        'BELONG_INDUSTRY': '所属行业',
        'CHAIRMAN': '董事长',
        'EMP_NUM': '员工人数',
        'FOUND_DATE': '公司成立日期',
        'ORG_EMAIL': 'E-MAIL',
        'ORG_EN_ABBR': '英文名称',
        'ORG_FAX': '传真',
        'ORG_NAME': '公司名称',
        'ORG_PROFILE': '公司介绍',
        'ORG_TEL': '联系电话',
        'ORG_WEB': '公司网址',
        'REG_ADDRESS': '注册地址',
        'REG_PLACE': '注册地',
        'SECRETARY': '公司秘书',
        'SECUCODE': '股票代码',
        'SECURITY_CODE': '证券代码',
        'YEAR_SETTLE_DAY': '年结日'
    }
    temp_df.rename(columns=field_mapping, inplace=True)
    temp_df = temp_df[[
        "公司名称",
        "英文名称",
        "注册地",
        "注册地址",
        "公司成立日期",
        "所属行业",
        "董事长",
        "公司秘书",
        "员工人数",
        "办公地址",
        "公司网址",
        "E-MAIL",
        "年结日",
        "联系电话",
        "核数师",
        "传真",
        "公司介绍",
    ]]
    return temp_df


def stock_hk_financial_indicator_em(symbol: str = "03900") -> pd.DataFrame:
    """
    东方财富-港股-核心必读-最新指标
    https://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=03900&type=web&color=w#/CoreReading
    :param symbol: 股票代码
    :type symbol: str
    :return: 财务指标
    :rtype: pandas.DataFrame
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'
    params = {
        'reportName': 'RPT_CUSTOM_HKF10_FN_MAININDICATORMAX',
        'columns': 'ORG_CODE,SECUCODE,SECURITY_CODE,SECURITY_NAME_ABBR,SECURITY_INNER_CODE,REPORT_DATE,BASIC_EPS,'
                   'PER_NETCASH_OPERATE,BPS,BPS_NEDILUTED,COMMON_ACS,PER_SHARES,ISSUED_COMMON_SHARES,HK_COMMON_SHARES,'
                   'TOTAL_MARKET_CAP,HKSK_MARKET_CAP,OPERATE_INCOME,OPERATE_INCOME_SQ,OPERATE_INCOME_QOQ,'
                   'OPERATE_INCOME_QOQ_SQ,HOLDER_PROFIT,HOLDER_PROFIT_SQ,HOLDER_PROFIT_QOQ,HOLDER_PROFIT_QOQ_SQ,PE_TTM,'
                   'PE_TTM_SQ,PB_TTM,PB_TTM_SQ,NET_PROFIT_RATIO,NET_PROFIT_RATIO_SQ,ROE_AVG,ROE_AVG_SQ,ROA,'
                   'ROA_SQ,DIVIDEND_TTM,DIVIDEND_LFY,DIVI_RATIO,DIVIDEND_RATE,IS_CNY_CODE',
        'quoteColumns': '',
        'filter': f'(SECUCODE="{symbol}.HK")',
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '-1',
        'sortColumns': 'REPORT_DATE',
        'source': 'F10',
        'client': 'PC',
        'v': '07945646099062258'
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['result']['data'])
    field_mapping = {
        'SECURITY_CODE': '股票代码',
        'BASIC_EPS': '基本每股收益(元)',
        'BPS': '每股净资产(元)',
        'COMMON_ACS': '法定股本(股)',
        'PER_SHARES': '每手股',
        'DIVIDEND_TTM': '每股股息TTM(港元)',
        'DIVI_RATIO': '派息比率(%)',
        'ISSUED_COMMON_SHARES': '已发行股本(股)',
        'HK_COMMON_SHARES': '已发行股本-H股(股)',
        'PER_NETCASH_OPERATE': '每股经营现金流(元)',
        'DIVIDEND_RATE': '股息率TTM(%)',
        'TOTAL_MARKET_CAP': '总市值(港元)',
        'HKSK_MARKET_CAP': '港股市值(港元)',
        'OPERATE_INCOME': '营业总收入',
        'OPERATE_INCOME_QOQ': '营业总收入滚动环比增长(%)',
        'NET_PROFIT_RATIO': '销售净利率(%)',
        'HOLDER_PROFIT': '净利润',
        'HOLDER_PROFIT_QOQ': '净利润滚动环比增长(%)',
        'ROE_AVG': '股东权益回报率(%)',
        'PE_TTM': '市盈率',
        'PB_TTM': '市净率',
        'ROA': '总资产回报率(%)'
    }
    temp_df.rename(columns=field_mapping, inplace=True)
    temp_df = temp_df[[
        "基本每股收益(元)",
        "每股净资产(元)",
        "法定股本(股)",
        "每手股",
        "每股股息TTM(港元)",
        "派息比率(%)",
        "已发行股本(股)",
        "已发行股本-H股(股)",
        "每股经营现金流(元)",
        "股息率TTM(%)",
        "总市值(港元)",
        "港股市值(港元)",
        "营业总收入",
        "营业总收入滚动环比增长(%)",
        "销售净利率(%)",
        "净利润",
        "净利润滚动环比增长(%)",
        "股东权益回报率(%)",
        "市盈率",
        "市净率",
        "总资产回报率(%)"

    ]]
    return temp_df


def stock_hk_dividend_payout_em(symbol: str = "03900") -> pd.DataFrame:
    """
    东方财富-港股-核心必读-分红派息
    https://emweb.securities.eastmoney.com/PC_HKF10/pages/home/index.html?code=03900&type=web&color=w#/CoreReading
    :param symbol: 股票代码
    :type symbol: str
    :return: 分红派息
    :rtype: pandas.DataFrame
    """
    url = 'https://datacenter.eastmoney.com/securities/api/data/v1/get'
    params = {
        'reportName': 'RPT_HKF10_MAIN_DIVBASIC',
        'columns': 'SECURITY_CODE,UPDATE_DATE,REPORT_TYPE,EX_DIVIDEND_DATE,DIVIDEND_DATE,'
                   'TRANSFER_END_DATE,YEAR,PLAN_EXPLAIN,IS_BFP',
        'quoteColumns': '',
        'filter': f'(SECURITY_CODE="{symbol}")(IS_BFP="0")',
        'pageNumber': '1',
        'pageSize': '200',
        'sortTypes': '-1,-1',
        'sortColumns': 'NOTICE_DATE,EX_DIVIDEND_DATE',
        'source': 'F10',
        'client': 'PC',
        'v': '035584639294227527'
    }
    r = requests.get(url, params=params)
    data_json = r.json()

    field_mapping = {
        'SECURITY_CODE': '股票代码',
        'UPDATE_DATE': '最新公告日期',
        'REPORT_TYPE': '分配类型',
        'EX_DIVIDEND_DATE': '除净日',
        'DIVIDEND_DATE': '发放日',
        'TRANSFER_END_DATE': '截至过户日',
        'YEAR': '财政年度',
        'PLAN_EXPLAIN': '分红方案',
        'IS_BFP': 'IS_BFP'
    }
    columns = [
        "最新公告日期",
        "财政年度",
        "分红方案",
        "分配类型",
        "除净日",
        "截至过户日",
        "发放日",
    ]

    temp_df = pd.DataFrame(columns=columns)
    if data_json['result'] is not None:
        temp_df = pd.DataFrame(data_json['result']['data'])
        temp_df.rename(columns=field_mapping, inplace=True)
        temp_df = temp_df[columns]
        temp_df['最新公告日期'] = pd.to_datetime(temp_df['最新公告日期'], errors='coerce').dt.date
        temp_df['除净日'] = pd.to_datetime(temp_df['除净日'], errors='coerce').dt.date
        temp_df['发放日'] = pd.to_datetime(temp_df['发放日'], format='%Y-%m-%d', errors='coerce').dt.date
    return temp_df


if __name__ == "__main__":
    stock_hk_security_profile_em_df = stock_hk_security_profile_em(symbol="03900")
    print(stock_hk_security_profile_em_df)

    stock_hk_company_profile_em_df = stock_hk_company_profile_em(symbol="03900")
    print(stock_hk_company_profile_em_df)

    stock_hk_financial_indicator_em_df = stock_hk_financial_indicator_em(symbol="03900")
    print(stock_hk_financial_indicator_em_df)

    stock_hk_dividend_payout_em_df = stock_hk_dividend_payout_em(symbol="03900")
    print(stock_hk_dividend_payout_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/4/10 18:24
Desc: 彭博亿万富豪指数
https://www.bloomberg.com/billionaires/
"""

import pandas as pd
import requests
from bs4 import BeautifulSoup


def index_bloomberg_billionaires_hist(year: str = "2021") -> pd.DataFrame:
    """
    Bloomberg Billionaires Index
    https://stats.areppim.com/stats/links_billionairexlists.htm
    :param year: choice of {"2021", "2019", "2018", ...}
    :type year: str
    :return: 彭博亿万富豪指数历史数据
    :rtype: pandas.DataFrame
    """
    url = f"https://stats.areppim.com/listes/list_billionairesx{year[-2:]}xwor.htm"
    r = requests.get(url)
    soup = BeautifulSoup(r.text, "lxml")
    trs = soup.findAll("table")[0].findAll("tr")
    heads = trs[1]
    if "Rank" not in heads.text:
        heads = trs[0]
    dic_keys = []
    dic = {}
    for head in heads:
        head = head.text
        dic_keys.append(head)
    for dic_key in dic_keys:
        dic[dic_key] = []

    for ll in trs:
        item = ll.findAll("td")
        for i in range(len(item)):
            v = item[i].text
            if i == 0 and not v.isdigit():
                break
            dic[dic_keys[i]].append(v)

    temp_df = pd.DataFrame(dic)
    temp_df = temp_df.rename(
        {
            "Rank": "rank",
            "Name": "name",
            "Age": "age",
            "Citizenship": "country",
            "Country": "country",
            "Net Worth(bil US$)": "total_net_worth",
            "Total net worth$Billion": "total_net_worth",
            "$ Last change": "last_change",
            "$ YTD change": "ytd_change",
            "Industry": "industry",
        },
        axis=1,
    )
    return temp_df


def index_bloomberg_billionaires() -> pd.DataFrame:
    """
    Bloomberg Billionaires Index
    https://www.bloomberg.com/billionaires/
    :return: 彭博亿万富豪指数
    :rtype: pandas.DataFrame
    """
    url = "https://www.bloomberg.com/billionaires"
    headers = {
        "accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "zh-CN,zh;q=0.9,en;q=0.8",
        "cache-control": "no-cache",
        "pragma": "no-cache",
        "sec-fetch-dest": "document",
        "sec-fetch-mode": "navigate",
        "sec-fetch-site": "same-origin",
        "sec-fetch-user": "?1",
        "upgrade-insecure-requests": "1",
        "referer": "https://www.bloomberg.com/",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/83.0.4103.116 Safari/537.36",
    }
    r = requests.get(url, headers=headers)
    soup = BeautifulSoup(r.text, "lxml")
    big_content_list = list()
    soup_node = soup.find(attrs={"class": "table-chart"}).find_all(
        attrs={"class": "table-row"}
    )
    for row in soup_node:
        temp_content_list = row.text.strip().replace("\n", "").split("  ")
        content_list = [item for item in temp_content_list if item != ""]
        big_content_list.append(content_list)
    temp_df = pd.DataFrame(big_content_list)
    temp_df.columns = [
        "rank",
        "name",
        "total_net_worth",
        "last_change",
        "YTD_change",
        "country",
        "industry",
    ]
    return temp_df


if __name__ == "__main__":
    index_bloomberg_billionaires_df = index_bloomberg_billionaires()
    print(index_bloomberg_billionaires_df)

    index_bloomberg_billionaires_hist_df = index_bloomberg_billionaires_hist(
        year="2021"
    )
    print(index_bloomberg_billionaires_hist_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/10/1 17:00
Desc: 中国外汇交易中心暨全国银行间同业拆借中心
中国外汇交易中心暨全国银行间同业拆借中心-市场数据-债券市场行情-现券市场做市报价
中国外汇交易中心暨全国银行间同业拆借中心-市场数据-债券市场行情-现券市场成交行情
https://www.chinamoney.com.cn/chinese/mkdatabond/
"""

from io import StringIO

import pandas as pd
import requests

from akshare.bond.bond_china_money import bond_china_close_return_map
from akshare.utils.cons import headers


def bond_spot_quote() -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-市场数据-债券市场行情-现券市场做市报价
    https://www.chinamoney.com.cn/chinese/mkdatabond/
    :return: 现券市场做市报价
    :rtype: pandas.DataFrame
    """
    bond_china_close_return_map()
    url = "https://www.chinamoney.com.cn/ags/ms/cm-u-md-bond/CbMktMakQuot"
    payload = {
        "flag": "1",
        "lang": "cn",
    }
    r = requests.post(url=url, data=payload, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    temp_df.columns = [
        "_",
        "_",
        "报价机构",
        "_",
        "_",
        "_",
        "债券简称",
        "_",
        "_",
        "_",
        "_",
        "买入/卖出收益率",
        "_",
        "买入/卖出净价",
        "_",
        "_",
        "_",
    ]
    temp_df = temp_df[
        [
            "报价机构",
            "债券简称",
            "买入/卖出净价",
            "买入/卖出收益率",
        ]
    ]
    temp_df["买入净价"] = (
        temp_df["买入/卖出净价"].str.split("/", expand=True).iloc[:, 0]
    )
    temp_df["卖出净价"] = (
        temp_df["买入/卖出净价"].str.split("/", expand=True).iloc[:, 1]
    )
    temp_df["买入收益率"] = (
        temp_df["买入/卖出收益率"].str.split("/", expand=True).iloc[:, 0]
    )
    temp_df["卖出收益率"] = (
        temp_df["买入/卖出收益率"].str.split("/", expand=True).iloc[:, 1]
    )
    del temp_df["买入/卖出净价"]
    del temp_df["买入/卖出收益率"]
    temp_df["买入净价"] = pd.to_numeric(temp_df["买入净价"], errors="coerce")
    temp_df["卖出净价"] = pd.to_numeric(temp_df["卖出净价"], errors="coerce")
    temp_df["买入收益率"] = pd.to_numeric(temp_df["买入收益率"], errors="coerce")
    temp_df["卖出收益率"] = pd.to_numeric(temp_df["卖出收益率"], errors="coerce")
    return temp_df


def bond_spot_deal() -> pd.DataFrame:
    """
    中国外汇交易中心暨全国银行间同业拆借中心-市场数据-债券市场行情-现券市场成交行情
    https://www.chinamoney.com.cn/chinese/mkdatabond/
    :return: 现券市场成交行情
    :rtype: pandas.DataFrame
    """
    url = "https://www.chinamoney.com.cn/ags/ms/cm-u-md-bond/CbtPri"
    payload = {
        "flag": "1",
        "lang": "cn",
        "bondName": "",
    }
    r = requests.post(url=url, data=payload, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["records"])
    temp_df.columns = [
        "_",
        "_",
        "债券简称",
        "_",
        "_",
        "_",
        "_",
        "涨跌",
        "_",
        "_",
        "_",
        "加权收益率",
        "成交净价",
        "_",
        "_",
        "最新收益率",
        "-",
        "交易量",
        "_",
        "_",
        "_",
        "_",
    ]
    temp_df = temp_df[
        [
            "债券简称",
            "成交净价",
            "最新收益率",
            "涨跌",
            "加权收益率",
            "交易量",
        ]
    ]
    temp_df["成交净价"] = pd.to_numeric(temp_df["成交净价"], errors="coerce")
    temp_df["最新收益率"] = pd.to_numeric(temp_df["最新收益率"], errors="coerce")
    temp_df["涨跌"] = pd.to_numeric(temp_df["涨跌"], errors="coerce")
    temp_df["加权收益率"] = pd.to_numeric(temp_df["加权收益率"], errors="coerce")
    temp_df["交易量"] = pd.to_numeric(temp_df["交易量"], errors="coerce")
    return temp_df


def bond_china_yield(
    start_date: str = "20200204", end_date: str = "20210124"
) -> pd.DataFrame:
    """
    中国债券信息网-国债及其他债券收益率曲线
    https://www.chinabond.com.cn/
    https://yield.chinabond.com.cn/cbweb-pbc-web/pbc/historyQuery?startDate=2019-02-07&endDate=2020-02-04&gjqx=0&qxId=ycqx&locale=cn_ZH
    注意: end_date - start_date 应该小于一年
    :param start_date: 需要查询的日期, 返回在该日期之后一年内的数据
    :type start_date: str
    :param end_date: 需要查询的日期, 返回在该日期之前一年内的数据
    :type end_date: str
    :return: 返回在指定日期之间之前一年内的数据
    :rtype: pandas.DataFrame
    """
    url = "https://yield.chinabond.com.cn/cbweb-pbc-web/pbc/historyQuery"
    params = {
        "startDate": "-".join([start_date[:4], start_date[4:6], start_date[6:]]),
        "endDate": "-".join([end_date[:4], end_date[4:6], end_date[6:]]),
        "gjqx": "0",
        "qxId": "ycqx",
        "locale": "cn_ZH",
    }
    res = requests.get(url, params=params, headers=headers)
    data_text = res.text.replace("&nbsp", "")
    data_df = pd.read_html(StringIO(data_text), header=0)[1]
    data_df["日期"] = pd.to_datetime(data_df["日期"], errors="coerce").dt.date
    data_df["3月"] = pd.to_numeric(data_df["3月"], errors="coerce")
    data_df["6月"] = pd.to_numeric(data_df["6月"], errors="coerce")
    data_df["1年"] = pd.to_numeric(data_df["1年"], errors="coerce")
    data_df["3年"] = pd.to_numeric(data_df["3年"], errors="coerce")
    data_df["5年"] = pd.to_numeric(data_df["5年"], errors="coerce")
    data_df["7年"] = pd.to_numeric(data_df["7年"], errors="coerce")
    data_df["10年"] = pd.to_numeric(data_df["10年"], errors="coerce")
    data_df["30年"] = pd.to_numeric(data_df["30年"], errors="coerce")
    data_df.sort_values(by="日期", inplace=True)
    data_df.reset_index(inplace=True, drop=True)
    return data_df


if __name__ == "__main__":
    bond_spot_quote_df = bond_spot_quote()
    print(bond_spot_quote_df)

    bond_spot_deal_df = bond_spot_deal()
    print(bond_spot_deal_df)

    bond_china_yield_df = bond_china_yield(start_date="20210201", end_date="20220201")
    print(bond_china_yield_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2024/3/16 9:00
Desc:中国银行间市场交易商协会(https://www.nafmii.org.cn/)
孔雀开屏(http://zhuce.nafmii.org.cn/fans/publicQuery/manager)的债券基本信息数据
"""

import pandas as pd
import requests


def bond_debt_nafmii(page: str = "1") -> pd.DataFrame:
    """
    中国银行间市场交易商协会-非金融企业债务融资工具注册信息系统
    http://zhuce.nafmii.org.cn/fans/publicQuery/manager
    :param page: 输入数字页码
    :type page: int
    :return: 指定 sector 和 indicator 的数据
    :rtype: pandas.DataFrame
    """
    url = "http://zhuce.nafmii.org.cn/fans/publicQuery/releFileProjDataGrid"
    payload = {
        "regFileName": "",
        "itemType": "",
        "startTime": "",
        "endTime": "",
        "entityName": "",
        "leadManager": "",
        "regPrdtType": "",
        "page": page,
        "rows": 50,
    }
    payload.update({"page": page})
    r = requests.post(url, data=payload)
    data_json = r.json()  # 数据类型为 json 格式
    temp_df = pd.DataFrame(data_json["rows"])
    temp_df.rename(
        columns={
            "firstIssueAmount": "金额",
            "isReg": "注册或备案",
            "regFileName": "债券名称",
            "regNoticeNo": "注册通知书文号",
            "regPrdtType": "品种",
            "releaseTime": "更新日期",
            "projPhase": "项目状态",
        },
        inplace=True,
    )
    if "注册通知书文号" not in temp_df.columns:
        temp_df["注册通知书文号"] = pd.NA
    temp_df = temp_df[
        [
            "债券名称",
            "品种",
            "注册或备案",
            "金额",
            "注册通知书文号",
            "更新日期",
            "项目状态",
        ]
    ]
    temp_df["金额"] = pd.to_numeric(temp_df["金额"], errors="coerce")
    temp_df["更新日期"] = pd.to_datetime(temp_df["更新日期"], errors="coerce").dt.date
    return temp_df


if __name__ == "__main__":
    bond_debt_nafmii_df = bond_debt_nafmii(page="1")
    print(bond_debt_nafmii_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2021/12/19 13:09
Desc: 东方财富网-数据中心-主力数据-基金持仓
http://data.eastmoney.com/zlsj/2020-06-30-1-2.html
"""

import pandas as pd
import requests


def stock_report_fund_hold(
    symbol: str = "基金持仓", date: str = "20210331"
) -> pd.DataFrame:
    """
    东方财富网-数据中心-主力数据-基金持仓
    http://data.eastmoney.com/zlsj/2020-12-31-1-2.html
    :param symbol: choice of {"基金持仓", "QFII持仓", "社保持仓", "券商持仓", "保险持仓", "信托持仓"}
    :type symbol: str
    :param date: 财报发布日期, xxxx-03-31, xxxx-06-30, xxxx-09-30, xxxx-12-31
    :type date: str
    :return: 基金持仓数据
    :rtype: pandas.DataFrame
    """
    symbol_map = {
        "基金持仓": "1",
        "QFII持仓": "2",
        "社保持仓": "3",
        "券商持仓": "4",
        "保险持仓": "5",
        "信托持仓": "6",
    }
    date = "-".join([date[:4], date[4:6], date[6:]])
    url = "http://data.eastmoney.com/dataapi/zlsj/list"
    params = {
        "date": date,
        "type": symbol_map[symbol],
        "zjc": "0",
        "sortField": "HOULD_NUM",
        "sortDirec": "1",
        "pageNum": "1",
        "pageSize": "500",
        "p": "1",
        "pageNo": "1",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json["pages"]
    big_df = pd.DataFrame()
    for page in range(1, total_page + 1):
        params = {
            "date": date,
            "type": symbol_map[symbol],
            "zjc": "0",
            "sortField": "HOULD_NUM",
            "sortDirec": "1",
            "pageNum": page,
            "pageSize": "500",
            "p": page,
            "pageNo": page,
        }
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"])
        big_df = pd.concat([big_df, temp_df], ignore_index=True)
    big_df.reset_index(inplace=True)
    big_df["index"] = list(range(1, len(big_df) + 1))
    big_df.columns = [
        "序号",
        "_",
        "股票简称",
        "_",
        "_",
        "持有基金家数",
        "持股总数",
        "持股市值",
        "_",
        "持股变化",
        "持股变动数值",
        "持股变动比例",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "股票代码",
        "_",
        "_",
    ]
    big_df = big_df[
        [
            "序号",
            "股票代码",
            "股票简称",
            "持有基金家数",
            "持股总数",
            "持股市值",
            "持股变化",
            "持股变动数值",
            "持股变动比例",
        ]
    ]
    return big_df


def stock_report_fund_hold_detail(
    symbol: str = "008286", date: str = "20220331"
) -> pd.DataFrame:
    """
    东方财富网-数据中心-主力数据-基金持仓-明细
    http://data.eastmoney.com/zlsj/ccjj/2020-12-31-008286.html
    :param symbol: 基金代码
    :type symbol: str
    :param date: 财报发布日期, xxxx-03-31, xxxx-06-30, xxxx-09-30, xxxx-12-31
    :type date: str
    :return: 基金持仓-明细数据
    :rtype: pandas.DataFrame
    """
    date = "-".join([date[:4], date[4:6], date[6:]])
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "SECURITY_CODE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_MAINDATA_MAIN_POSITIONDETAILS",
        "columns": "ALL",
        "quoteColumns": "",
        "filter": f"""(HOLDER_CODE="{symbol}")(REPORT_DATE='{date}')""",
        "source": "WEB",
        "client": "WEB",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.reset_index(inplace=True)
    temp_df["index"] = temp_df.index + 1
    temp_df.columns = [
        "序号",
        "-",
        "股票代码",
        "-",
        "股票简称",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "_",
        "持股数",
        "持股市值",
        "占总股本比例",
        "占流通股本比例",
        "_",
        "_",
    ]
    temp_df = temp_df[
        [
            "序号",
            "股票代码",
            "股票简称",
            "持股数",
            "持股市值",
            "占总股本比例",
            "占流通股本比例",
        ]
    ]
    temp_df["持股数"] = pd.to_numeric(temp_df["持股数"])
    temp_df["持股市值"] = pd.to_numeric(temp_df["持股市值"])
    temp_df["占总股本比例"] = pd.to_numeric(temp_df["占总股本比例"])
    temp_df["占流通股本比例"] = pd.to_numeric(temp_df["占流通股本比例"])
    return temp_df


if __name__ == "__main__":
    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="基金持仓", date="20200630"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="QFII持仓", date="20210331"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="社保持仓", date="20210331"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="券商持仓", date="20210331"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="保险持仓", date="20210331"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_df = stock_report_fund_hold(
        symbol="信托持仓", date="20210331"
    )
    print(stock_report_fund_hold_df)

    stock_report_fund_hold_detail_df = stock_report_fund_hold_detail(
        symbol="005827", date="20210331"
    )
    print(stock_report_fund_hold_detail_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/9/16 21:00
Desc: 天天基金-基金档案
https://fundf10.eastmoney.com/jbgk_015641.html
"""
from io import StringIO

import pandas as pd
import requests


def fund_overview_em(symbol: str = "015641") -> pd.DataFrame:
    """
    天天基金-基金档案-基本概况
    https://fundf10.eastmoney.com/jbgk_015641.html
    :param symbol: 基金代码
    :type symbol: str
    :return: 基本概况
    :rtype: pandas.DataFrame
    """
    url = f"https://fundf10.eastmoney.com/jbgk_{symbol}.html"
    r = requests.get(url)
    html_content = pd.read_html(StringIO(r.text))

    if len(html_content) == 0:
        temp_df = pd.DataFrame([])
    else:
        df_dict = {}
        # 最后一个表格的数据是我们想要的，按照Key-Value的形式存储
        for _, row in html_content[-1].iterrows():
            df_dict[row[0]] = row[1]
            df_dict[row[2]] = row[3]
        temp_df = pd.DataFrame([df_dict])

    return temp_df


if __name__ == "__main__":
    fund_overview_em_df = fund_overview_em(symbol="015641")
    print(fund_overview_em_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2025/7/1 16:30
Desc: 期货-仓单日报
上海期货交易所-仓单日报
https://tsite.shfe.com.cn/statements/dataview.html?paramid=dailystock
郑州商品交易所-交易数据-仓单日报
http://www.czce.com.cn/cn/jysj/cdrb/H770310index_1.htm
大连商品交易所-行情数据-统计数据-日统计-仓单日报
http://www.dce.com.cn/dalianshangpin/xqsj/tjsj26/rtj/cdrb/index.html
广州期货交易所-行情数据-仓单日报
http://www.gfex.com.cn/gfex/cdrb/hqsj_tjsj.shtml
"""

import re
from io import BytesIO, StringIO

import pandas as pd
import requests


def futures_czce_warehouse_receipt(date: str = "20200702") -> dict:
    """
    郑州商品交易所-交易数据-仓单日报
    http://www.czce.com.cn/cn/jysj/cdrb/H770310index_1.htm
    :param date: 交易日, e.g., "20200702"
    :type date: str
    :return: 指定日期的仓单日报数据
    :rtype: dict
    """
    import urllib3
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
    url = f"http://www.czce.com.cn/cn/DFSStaticFiles/Future/{date[:4]}/{date}/FutureDataWhsheet.xls"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                      "Chrome/83.0.4103.116 Safari/537.36"
    }
    r = requests.get(url, verify=False, headers=headers)
    temp_df = pd.read_excel(BytesIO(r.content))
    index_list = temp_df[temp_df.iloc[:, 0].str.find("品种") == 0.0].index.to_list()
    index_list.append(len(temp_df))
    big_dict = {}
    for inner_index in range(len(index_list) - 1):
        inner_df = temp_df[index_list[inner_index]: index_list[inner_index + 1]]
        inner_key = re.findall(r"[a-zA-Z]+", inner_df.iloc[0, 0])[0]
        inner_df = inner_df.iloc[1:, :]
        inner_df.dropna(axis=0, how="all", inplace=True)
        inner_df.dropna(axis=1, how="all", inplace=True)
        inner_df.columns = inner_df.iloc[0, :].to_list()
        inner_df = inner_df.iloc[1:, :]
        inner_df.reset_index(inplace=True, drop=True)
        big_dict[inner_key] = inner_df
    return big_dict


def futures_warehouse_receipt_dce(date: str = "20251027") -> pd.DataFrame:
    """
    大连商品交易所-行情数据-统计数据-日统计-仓单日报
    http://www.dce.com.cn/dce/channel/list/187.html
    :param date: 交易日, e.g., "20200702"
    :type date: str
    :return: 指定日期的仓单日报数据
    :rtype: dict
    """
    url = "http://www.dce.com.cn/dcereport/publicweb/dailystat/wbillWeeklyQuotes"
    payload = {
        "tradeDate": date,
        "varietyId": "all",
    }
    r = requests.post(url, json=payload)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json['data']['entityList'])
    temp_df.rename(columns={
        "variety": "品种名称",
        "whAbbr": "仓库/分库",
        "deliveryAbbr": "可选提货地点/分库-数量",
        "lastWbillQty": "昨日仓单量（手）",
        "wbillQty": "今日仓单量（手）",
        "diff": "增减（手）",
        "varietyOrder": "品种代码",
    }, inplace=True)
    temp_df = temp_df[[
        "品种代码",
        "品种名称",
        "仓库/分库",
        "可选提货地点/分库-数量",
        "昨日仓单量（手）",
        "今日仓单量（手）",
        "增减（手）",
    ]]
    return temp_df


def futures_shfe_warehouse_receipt(date: str = "20200702") -> dict:
    """
    上海期货交易所指定交割仓库期货仓单日报
    https://tsite.shfe.com.cn/statements/dataview.html?paramid=dailystock&paramdate=20200703
    :param date: 交易日, e.g., "20200702"
    :type date: str
    :return: 指定日期的仓单日报数据
    :rtype: dict
    """
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                      "Chrome/83.0.4103.116 Safari/537.36"
    }
    url = f"https://www.shfe.com.cn/data/tradedata/future/dailydata/{date}dailystock.dat"
    if date >= "20140519":
        r = requests.get(url, headers=headers)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["o_cursor"])
        temp_df["VARNAME"] = temp_df["VARNAME"].str.split(r"$", expand=True).iloc[:, 0]
        temp_df["REGNAME"] = temp_df["REGNAME"].str.split(r"$", expand=True).iloc[:, 0]
        temp_df["WHABBRNAME"] = (
            temp_df["WHABBRNAME"].str.split(r"$", expand=True).iloc[:, 0]
        )
        big_dict = {}
        for item in set(temp_df["VARNAME"]):
            big_dict[item] = temp_df[temp_df["VARNAME"] == item]
    else:
        url = f"https://www.shfe.com.cn/data/tradedata/future/dailydata/{date}dailystock.html"
        r = requests.get(url, headers=headers)
        temp_df = pd.read_html(StringIO(r.text))[0]
        index_list = temp_df[
            temp_df.iloc[:, 3].str.contains("单位：") == 1
            ].index.to_list()
        big_dict = {}
        for inner_index in range(len(index_list)):
            temp_index_start = index_list[inner_index]
            if (inner_index + 1) >= len(index_list):
                if temp_df.iloc[-1, 0].startswith("注："):
                    temp_index_end = len(temp_df) - 1
                else:
                    temp_index_end = len(temp_df)
            else:
                temp_index_end = index_list[inner_index + 1]
            inner_df = temp_df[temp_index_start:temp_index_end]
            inner_df.reset_index(inplace=True, drop=True)
            inner_key = inner_df.iloc[0, 0]
            inner_df.columns = inner_df.iloc[1].to_list()
            inner_df = inner_df[2:]
            inner_df.reset_index(inplace=True, drop=True)
            big_dict[inner_key] = inner_df
    return big_dict


def futures_gfex_warehouse_receipt(date: str = "20240122") -> dict:
    """
    广州期货交易所-行情数据-仓单日报
    http://www.gfex.com.cn/gfex/cdrb/hqsj_tjsj.shtml
    :param date: 交易日, e.g., "20240122"
    :type date: str
    :return: 指定日期的仓单日报数据
    :rtype: dict
    """
    url = "http://www.gfex.com.cn/u/interfacesWebTdWbillWeeklyQuotes/loadList"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) "
                      "Chrome/83.0.4103.116 Safari/537.36"
    }
    payload = {"gen_date": date}
    r = requests.post(url=url, data=payload, headers=headers)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["data"])
    symbol_list = list(
        set([item.upper() for item in temp_df["varietyOrder"].tolist() if item != ""])
    )
    temp_df.rename(
        columns={
            "varietyOrder": "symbol",
            "variety": "品种",
            "whAbbr": "仓库/分库",
            "lastWbillQty": "昨日仓单量",
            "wbillQty": "今日仓单量",
            "regWbillQty": "增减",
        },
        inplace=True,
    )
    temp_df = temp_df[
        [
            "symbol",
            "whType",
            "品种",
            "仓库/分库",
            "昨日仓单量",
            "今日仓单量",
            "增减",
        ]
    ]
    temp_df["whType"] = pd.to_numeric(temp_df["whType"], errors="coerce")
    temp_df.dropna(
        subset=["whType"], how="any", axis=0, ignore_index=True, inplace=True
    )
    big_dict = dict()
    for symbol in symbol_list:
        inner_temp_df = temp_df[temp_df["symbol"] == symbol.lower()].copy()
        inner_temp_df = inner_temp_df[
            [
                "品种",
                "仓库/分库",
                "昨日仓单量",
                "今日仓单量",
                "增减",
            ]
        ]
        inner_temp_df["昨日仓单量"] = pd.to_numeric(
            inner_temp_df["昨日仓单量"], errors="coerce"
        )
        inner_temp_df["今日仓单量"] = pd.to_numeric(
            inner_temp_df["今日仓单量"], errors="coerce"
        )
        inner_temp_df["增减"] = pd.to_numeric(inner_temp_df["增减"], errors="coerce")
        inner_temp_df.reset_index(inplace=True, drop=True)
        big_dict[symbol] = inner_temp_df
    return big_dict


if __name__ == "__main__":
    czce_warehouse_receipt_df = futures_czce_warehouse_receipt(date="20151019")
    print(czce_warehouse_receipt_df)

    futures_warehouse_receipt_dce_df = futures_warehouse_receipt_dce(date="20251014")
    print(futures_warehouse_receipt_dce_df)

    futures_shfe_warehouse_receipt_df = futures_shfe_warehouse_receipt(date="20200702")
    print(futures_shfe_warehouse_receipt_df)

    futures_shfe_warehouse_receipt_df = futures_shfe_warehouse_receipt(date="20140516")
    print(futures_shfe_warehouse_receipt_df)

    futures_gfex_warehouse_receipt_df = futures_gfex_warehouse_receipt(date="20240122")
    print(futures_gfex_warehouse_receipt_df)



#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
Date: 2022/9/21 16:49
Desc: 东方财富网-数据中心-特色数据-券商业绩月报
http://data.eastmoney.com/other/qsjy.html
"""

import pandas as pd
import requests


def stock_qsjy_em(date: str = "20200731") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-券商业绩月报
    http://data.eastmoney.com/other/qsjy.html
    :param date: 数据月份，从 2010-06-01 开始, e.g., 需要 2011 年 7 月, 则输入 2011-07-01
    :type date: str
    :return: 券商业绩月报
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "END_DATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_PERFORMANCE",
        "columns": "SECURITY_CODE,SECURITY_NAME_ABBR,END_DATE,NETPROFIT,NP_YOY,NP_QOQ,ACCUMPROFIT,ACCUMPROFIT_YOY,OPERATE_INCOME,OI_YOY,OI_QOQ,ACCUMOI,ACCUMOI_YOY,NET_ASSETS,NA_YOY",
        "source": "WEB",
        "client": "WEB",
        "filter": f"(END_DATE='{'-'.join([date[:4], date[4:6], date[6:]])}')",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(data_json["result"]["data"])
    temp_df.columns = [
        "代码",
        "简称",
        "-",
        "当月净利润-净利润",
        "当月净利润-同比增长",
        "当月净利润-环比增长",
        "当年累计净利润-累计净利润",
        "当年累计净利润-同比增长",
        "当月营业收入-营业收入",
        "当月营业收入-环比增长",
        "当月营业收入-同比增长",
        "当年累计营业收入-累计营业收入",
        "当年累计营业收入-同比增长",
        "净资产-净资产",
        "净资产-同比增长",
    ]
    temp_df = temp_df[
        [
            "简称",
            "代码",
            "当月净利润-净利润",
            "当月净利润-同比增长",
            "当月净利润-环比增长",
            "当年累计净利润-累计净利润",
            "当年累计净利润-同比增长",
            "当月营业收入-营业收入",
            "当月营业收入-环比增长",
            "当月营业收入-同比增长",
            "当年累计营业收入-累计营业收入",
            "当年累计营业收入-同比增长",
            "净资产-净资产",
            "净资产-同比增长",
        ]
    ]
    temp_df["当月净利润-净利润"] = pd.to_numeric(temp_df["当月净利润-净利润"])
    temp_df["当月净利润-同比增长"] = pd.to_numeric(temp_df["当月净利润-同比增长"])
    temp_df["当月净利润-环比增长"] = pd.to_numeric(temp_df["当月净利润-环比增长"])
    temp_df["当年累计净利润-累计净利润"] = pd.to_numeric(
        temp_df["当年累计净利润-累计净利润"]
    )
    temp_df["当年累计净利润-同比增长"] = pd.to_numeric(
        temp_df["当年累计净利润-同比增长"]
    )
    temp_df["当月营业收入-营业收入"] = pd.to_numeric(temp_df["当月营业收入-营业收入"])
    temp_df["当月营业收入-环比增长"] = pd.to_numeric(temp_df["当月营业收入-环比增长"])
    temp_df["当月营业收入-同比增长"] = pd.to_numeric(temp_df["当月营业收入-同比增长"])
    temp_df["当年累计营业收入-累计营业收入"] = pd.to_numeric(
        temp_df["当年累计营业收入-累计营业收入"]
    )
    temp_df["当年累计营业收入-同比增长"] = pd.to_numeric(
        temp_df["当年累计营业收入-同比增长"]
    )
    temp_df["净资产-净资产"] = pd.to_numeric(temp_df["净资产-净资产"])
    temp_df["净资产-同比增长"] = pd.to_numeric(temp_df["净资产-同比增长"])
    return temp_df


if __name__ == "__main__":
    stock_qsjy_em_df = stock_qsjy_em(date="20200430")
    print(stock_qsjy_em_df)



# -*- coding:utf-8 -*-
# !/usr/bin/env python
"""
Date: 2025/10/29 15:00
Desc: 中证商品指数
http://www.ccidx.com/
"""

import json

import pandas as pd
import requests


def futures_index_ccidx(symbol: str = "中证商品期货指数") -> pd.DataFrame:
    """
    中证商品指数-商品指数-日频率
    http://www.ccidx.com/index.html
    :param symbol: choice of {"中证商品期货指数", "中证商品期货价格指数"}
    :type symbol: str
    :return: 商品指数-日频率
    :rtype: pandas.DataFrame
    """
    futures_index_map = {
        "中证商品期货指数": "100001.CCI",
        "中证商品期货价格指数": "000001.CCI",
    }
    url = "http://www.ccidx.com/CCI-ZZZS/index/getDateLine"
    params = {"indexId": futures_index_map[symbol]}
    r = requests.get(url, params=params)
    data_json = r.json()
    temp_df = pd.DataFrame(
        [json.loads(item) for item in data_json["data"]["dateLineJson"]]
    )
    temp_df.rename(
        columns={
            "tradeDate": "日期",
            "indexId": "指数代码",
            "closingPrice": "收盘点位",
            "settlePrice": "结算点位",
            "dailyIncreaseAndDecrease": "涨跌",
            "dailyIncreaseAndDecreasePercentage": "涨跌幅",
        },
        inplace=True,
    )

    temp_df["日期"] = pd.to_datetime(temp_df["日期"], errors="coerce").dt.date
    temp_df["收盘点位"] = pd.to_numeric(temp_df["收盘点位"], errors="coerce")
    temp_df["结算点位"] = pd.to_numeric(temp_df["结算点位"], errors="coerce")
    temp_df["涨跌"] = pd.to_numeric(temp_df["涨跌"], errors="coerce")
    temp_df["涨跌幅"] = pd.to_numeric(temp_df["涨跌幅"], errors="coerce")
    temp_df.sort_values(by=["日期"], inplace=True)
    temp_df.reset_index(inplace=True, drop=True)
    return temp_df


if __name__ == "__main__":
    futures_index_ccidx_df = futures_index_ccidx(symbol="中证商品期货指数")
    print(futures_index_ccidx_df)
